@@ -9,7 +9,7 @@ from .dependence import partialdep
 from .expectations import condexp
 from .importance import varimp
 from .shap import ShapExplainer
-from .utils import create_description, df_to_dict, replace_unserializable
+from .utils import create_description, df_to_dict, df_to_serializable_dict
 
 BASE_RESULTS_PATH = os.environ.get("BASE_RESULTS_PATH", "results")
 
@@ -49,7 +49,7 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
     baseline, explanation = explainer.explain(x)
 
     example = {
-        "inputs": [replace_unserializable(x.iloc[0]).to_dict()],
+        "inputs": [df_to_serializable_dict(x.iloc[0])],
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
