@@ -115,6 +115,9 @@ def vega_sanitize(var, datatype=None):
     return var
 
 
-def replace_unserializable(series):
+def df_to_serializable_dict(series):
     """Transform numpy types that can't be serialized to ones that can"""
-    return series.replace({np.nan: None, np.inf: None})
+    return {
+        key: val.item() if isinstance(val, np.generic) else val
+        for key, val in series.replace({np.nan: None, np.inf: None}).to_dict().items()
+    }
